/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: fileproperties.cpp
         Start Date: sometime 2009
       Last Changed: $LastChangedDate: 2011-04-09 00:17:11 +1200 (Sat, 09 Apr 2011) $
           Revision: $Revision: 295 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2009,2010
            License: GNU General Public License
   File Description: File Properties dialog
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/

#include "fileproperties.h"
#include "ui_fileproperties.h"

FileProperties::FileProperties(QWidget *parent) :
    QDialog(parent),
    m_ui(new Ui::FileProperties)
{
    m_ui->setupUi(this);
    connect(m_ui->buttonBox,SIGNAL(rejected()),this,SLOT(closeAndDelete()));
}

FileProperties::~FileProperties()
{
    delete m_ui;
}

void FileProperties::closeAndDelete() {
    this->deleteLater();
    reject();
}

void FileProperties::setFileEntry(FSEntry2 *e) {
    m_ui->lblIcon->setPixmap(e->getIcon().pixmap(32,32));
    m_ui->leFileName->setText(e->fileName());
    QString path = e->path();
    if (path.startsWith("/"))
        m_ui->leLocation->setText(QDir::toNativeSeparators(e->path()));
    else
        m_ui->leLocation->setText(QDir::toNativeSeparators("/" + e->path()));

    if (e->isDirectory())
        m_ui->leType->setText("Directory");
    else
        m_ui->leType->setText(e->suffix() + " File");


    if (!e->isDirectory()) {
        // Compute the size
        quint64 sz = e->getSize();
        QString unit = " B";

        // Are we kilobytes?
        if (sz > 1024) {
            sz /= 1024;
            unit = " KB";
        }

        // Are we megabytes?
        if (sz > 1024) {
            sz /= 1024;
            unit = " MB";
        }

        // are we gigabytes? (thats one huge floppy disk)
        if (sz > 1024) {
            sz /= 1024;
            unit = " GB";
        }

        m_ui->lblSize->setText(QString::number(sz,10) + unit);
    } else { m_ui->lblSize->setText(""); }

    m_ui->lblDOSFilename->setText(e->altFileName());

    // Attributes
    FSPlugin::Attributes a = e->getAttributes();
    m_ui->chkArchive->setChecked(a.testFlag(FSPlugin::A_Archive));
    m_ui->chkHidden->setChecked(a.testFlag(FSPlugin::A_Hidden));
    m_ui->chkReadOnly->setChecked(a.testFlag(FSPlugin::A_ReadOnly));
    m_ui->chkSystem->setChecked(a.testFlag(FSPlugin::A_System));

    // Date created
    if (e->getDate(FSEntry::D_CreatedDate).isValid()) {
        m_ui->dteCreated->setDate(e->getDate(FSEntry::D_CreatedDate));
        m_ui->dteCreated->setTime(e->getTime(FSEntry::D_CreatedTime));
        m_ui->dteCreated->setReadOnly(true);
    }
    else {
        m_ui->dteCreated->setEnabled(false);
        m_ui->dteCreated->setDateTime(QDateTime::currentDateTime());
    }

    // Date modified
    if (e->getDate(FSEntry::D_ModifiedDate).isValid()) {
        m_ui->dteModified->setDate(e->getDate(FSEntry::D_ModifiedDate));
        m_ui->dteModified->setTime(e->getTime(FSEntry::D_ModifiedTime));
        m_ui->dteModified->setReadOnly(true);
    } else {
        m_ui->dteModified->setEnabled(false);
        m_ui->dteModified->setDateTime(QDateTime::currentDateTime());
    }

    // Date accessed
    if (e->getDate(FSEntry::D_AccessedDate).isValid()) {
        m_ui->deAccessed->setDate(e->getDate(FSEntry::D_AccessedDate));
        m_ui->deAccessed->setReadOnly(true);
    }
    else {
        m_ui->deAccessed->setEnabled(false);
        m_ui->deAccessed->setDate(QDate::currentDate());
    }
}

void FileProperties::changeEvent(QEvent *e)
{
    switch (e->type()) {
    case QEvent::LanguageChange:
        m_ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
