/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: settingsdialog.cpp
         Start Date: 29/03/2010
       Last Changed: $LastChangedDate: 2011-04-09 00:17:11 +1200 (Sat, 09 Apr 2011) $
           Revision: $Revision: 295 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
   File Description: Settings dialog
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/

#include "settingsdialog.h"
#include "ui_settingsdialog.h"
#include <QtDebug>
#include <QMessageBox>
#include <QFileDialog>

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SettingsDialog)
{
    ui->setupUi(this);
    connect(ui->buttonBox,
            SIGNAL(accepted()),
            this,
            SLOT(settingsAccepted()));
    connect(ui->hsCompressionLevel,
            SIGNAL(valueChanged(int)),
            this,
            SLOT(compressionSliderMoved(int)));
    connect(ui->pbBrowseStyleSheet,SIGNAL(clicked()),this,SLOT(browseForStyleFile()));


    QScopedPointer<QSettings> settings;
    QString settingsFile;
    settingsFile = QCoreApplication::applicationName() + ".ini";
    qDebug() << "Checking for configuration file " << settingsFile;

    if (QFile::exists(settingsFile)) {
        // Load settings from there
        settings.reset(new QSettings(settingsFile, QSettings::IniFormat, 0));
    } else {
        settings.reset(new QSettings());
    }
    qDebug() << "Settings Loaded.";

    QString styleName = settings->value("UI/Style","PlatformDefault").toString().toUpper();
    QString styleSheet = settings->value("UI/StyleSheetFile","").toString();
    int compressionLevel = settings->value("FileHandling/CompressionLevel",6).toInt();
    bool askForComment = settings->value("FileHandling/AskForComment", false).toBool();

    ui->cbAskForComment->setChecked(askForComment);
    ui->hsCompressionLevel->setValue(compressionLevel);
    compressionSliderMoved(compressionLevel);
    ui->leStyleSheet->setText(styleSheet);

    /* When adding new styles, add it to the end of cbItems and the start of
       the switch statement. Remember to update settingsAccepted() too.
     */
    QStringList cbItems;
    cbItems << "Platform Default";
    cbItems << "Cleanlooks";
    cbItems << "Plastique";
    cbItems << "Windows";
    cbItems << "CDE";
    cbItems << "Motif";
    ui->cbAppStyle->addItems(cbItems);

    if (styleName == "MOTIF")
        ui->cbAppStyle->setCurrentIndex(5);
    else if (styleName == "CDE")
        ui->cbAppStyle->setCurrentIndex(4);
    else if (styleName == "WINDOWS")
        ui->cbAppStyle->setCurrentIndex(3);
    else if (styleName == "PLASTIQUE")
        ui->cbAppStyle->setCurrentIndex(2);
    else if (styleName == "CLEANLOOKS")
        ui->cbAppStyle->setCurrentIndex(1);
    else
        ui->cbAppStyle->setCurrentIndex(0);

    oldStyle = ui->cbAppStyle->currentIndex();
    oldStyleFile = styleSheet;
}

SettingsDialog::~SettingsDialog()
{
    delete ui;
}

void SettingsDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void SettingsDialog::settingsAccepted() {
    QScopedPointer<QSettings> settings;
    QString settingsFile;
    settingsFile = QCoreApplication::applicationName() + ".ini";
    qDebug() << "Checking for configuration file " << settingsFile;

    if (QFile::exists(settingsFile)) {
        // Load settings from there
        settings.reset(new QSettings(settingsFile, QSettings::IniFormat, 0));
    } else {
        settings.reset(new QSettings());
    }
    qDebug() << "Settings Loaded.";

    QString styleName;
    switch (ui->cbAppStyle->currentIndex()) {
    case 5:
        styleName = "Motif";
        break;
    case 4:
        styleName = "CDE";
        break;
    case 3:
        styleName = "Windows";
        break;
    case 2:
        styleName = "Plastique";
        break;
    case 1:
        styleName = "Cleanlooks";
        break;
    case 0:
    default:
        styleName = "PlatformDefault";
    }

    if (oldStyle != ui->cbAppStyle->currentIndex()
        || oldStyleFile != ui->leStyleSheet->text())
        QMessageBox::information(this,"Restart Application","You must restart the application "
                                 "for the application style settings to take effect");

    QString styleSheet = ui->leStyleSheet->text();
    int compressionLevel = ui->hsCompressionLevel->value();
    bool askForComment = ui->cbAskForComment->isChecked();

    settings->setValue("UI/Style",styleName);
    settings->setValue("UI/StyleSheetFile",styleSheet);
    settings->setValue("FileHandling/CompressionLevel",compressionLevel);
    settings->setValue("FileHandling/AskForComment",askForComment);

    accept();
}

void SettingsDialog::compressionSliderMoved(int value) {
    switch (value) {
    case 0:
        ui->lblCompressionDescription->setText("No Compression (0)");
        break;
    case 1:
        ui->lblCompressionDescription->setText("Minimum / fastest (1)");
        break;
    case 2:
        ui->lblCompressionDescription->setText("Almost minimum - incase you have an 286 (2)");
        break;
    case 3:
        ui->lblCompressionDescription->setText("Compression level 3");
        break;
    case 4:
        ui->lblCompressionDescription->setText("Compression level 4");
        break;
    case 5:
        ui->lblCompressionDescription->setText("Less than Normal (larger file size) (5)");
        break;
    case 6:
        ui->lblCompressionDescription->setText("Normal (6)");
        break;
    case 7:
        ui->lblCompressionDescription->setText("Better than Normal (smaller file size) (7)");
        break;
    case 8:
        ui->lblCompressionDescription->setText("Almost but not quite Maximum (8)");
        break;
    case 9:
        ui->lblCompressionDescription->setText("Maximum (slowest, smallest file size) (9)");
        break;
    default:
        ui->lblCompressionDescription->setText("");
    }
}

void SettingsDialog::browseForStyleFile() {
    ui->leStyleSheet->setText(QFileDialog::getOpenFileName(this,"Select StyleSheet"));

}
