/*
-----------------------------------------------------
   Application Name: DIMG - FSContainer
          File Name: mainwindow.h
         Start Date: unknown - ask subversion.
       Last Changed: $LastChangedDate: 2011-04-09 00:17:11 +1200 (Sat, 09 Apr 2011) $
           Revision: $Revision: 295 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2008,2009,2010
            License: GNU General Public License
   File Description: FSContainer Main Window header
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QMainWindow>
#include <QFileDialog>
#include <QtDebug>
#include <QFile>
#include <QTreeWidgetItem>
#include <QPluginLoader>
#include <QMessageBox>
#include <FSPlugin.h>
#include <fsentry.h>
#include "aboutdialog.h"
#include "fileproperties.h"

namespace Ui
{
    class MainWindowClass;
}

/** The applications Main Window.
 */
class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = 0);    /*!< Constructor */
    ~MainWindow();  /*!< Destructor */

    void loadPlugin();

public slots:
    void open();    /*!< Displays an open-file dialog */
    /** Opens the specified file.
      \param filename The Disk Image to load.
     */
    void open(QString filename);
    void exit(); /*!< Exits the program */

    void extract_file(); /*!< Extracts the currently selected file */

    void show_file_properties(); /*!< Shows the properties of the currently selected file */

    void show_about();  /*!< Shows the plugins about dialog */

    void show_configure();  /*!< Shows the plugins configure dialog */

    void show_app_about(); /*!< Shows the applications about dialog */

private:
    /** A recursive function that populates the file tree.

      \param parent The parent widget
      \param directory The directory to load.
     */
    void populateTree(QTreeWidgetItem *parent, QString directory);
    Ui::MainWindowClass *ui;    /*!< The User Interface */
    QFile *file;    /*!< The file that the filesystem is working from */
    FSPlugin *p;     /*!< The plugin which provides our filesystem */
};

#endif // MAINWINDOW_H
