/*
-----------------------------------------------------
   Application Name: "DIMG"
         Start Date: 10/07/2010
       Last Changed: $LastChangedDate: $
           Revision: $Revision: $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
-----------------------------------------------------
        This file is part of "DIMG".

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

        File Notes:
        ------------------
*/

#ifndef ERRORS_H
#define ERRORS_H

namespace FilesystemFAT {

    /** This namespace contains error codes and functions for
      dealing with them.
     */
    namespace Errors {

        /* NOTE: The source for Errors::errorToString() lives in
         * util.cpp.
         */

        /** Return codes used by FAT Filesystem classes and functions.
         */
        enum ReturnCode {
            SUCCESS,         /*!< There was no error. Everything is fine. */
            FAILURE,         /*!< Something went wrong. Don't know what. */
            BAD_PTR,         /*!< A bad pointer was detected. */
            SEEK_ERR,        /*!< Unknown Seek Error */
            SEEK_PAST_END,   /*!< Attempt to seek past end of file */
            INVALID_CLUSTER, /*!< The cluster number was invalid */
            NOT_ENOUGH_DATA, /*!< Not enough data was supplied */
            TOO_MUCH_DATA,   /*!< Too much data was supplied */
            FILE_NOT_FOUND,  /*!< The requested file could not be found */
            FS_IS_OPEN,      /*!< Filesystem is Open */
            FS_IS_CLOSED,    /*!< Filesystem is Closed */
            NO_DEVICE,       /*!< There was no device to open the Filesystem
                                  from */
            DEV_CLOSED,      /*!< Device is closed */
            INV_LFN_COMP,    /*!< Invalid long filename component. */
            LOOP_DETECTED,   /*!< Loop detected in file allocation table. */
            BPB_WARNING,     /*!< Error detected in BIOS Parameter Block. */
            FAT_RES_A,       /*!< Reserved value 0x001 encountered in FAT. */
            FAT_RES_B,       /*!< Reserved value between 0xFF0 and 0xFF6
                                  encountered in FAT. */
            FAT_CLUST_BAD,  /*!< Encountered a cluster marked as BAD while
                                 loading the chain. */
            FAT_NO_FAT,     /*!< The BIOS Parameter Block reported there was
                                 no File Allocation Table present. */
            INV_FAT_LOC,    /*!< Invalid FAT Location (such as beyond EOF) */
            INV_FAT_SIZE,   /*!< Invalid FAT size (such as larger than file)*/
            BPB_FATAL       /*!< Fatal error trying to load BIOS Parameter Block */
        };
    }
}

#endif // ERRORS_H
