/*
-----------------------------------------------------
   Application Name: "DIMG"
         Start Date: 10/07/2010
       Last Changed: $LastChangedDate: $
           Revision: $Revision: $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
-----------------------------------------------------
        This file is part of "DIMG".

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

        File Notes:
        ------------------
*/

#include "util.h"

#include <QtDebug>

using namespace FilesystemFAT;

QString Errors::errorToString(Errors::ReturnCode err)
{
    using namespace Errors;

    switch (err) {
    case SUCCESS:
        return "Success";
    case FAILURE:
        return "Unknown Error";
    case BAD_PTR:
        return "Bad Pointer";
    case SEEK_ERR:
        return "Unknown Seek Error";
    case SEEK_PAST_END:
        return "Attempt to seek past end of file";
    case INVALID_CLUSTER:
        return "The requested cluster number is invalid";
    case NOT_ENOUGH_DATA:
        return "Not enough data was supplied";
    case TOO_MUCH_DATA:
        return "Too much data was supplied";
    case FILE_NOT_FOUND:
        return "File Not Found";
    case FS_IS_OPEN:
        return "Operation not permitted while filesystem is open";
    case FS_IS_CLOSED:
        return "Operation not permitted while filesystem is closed";
    case NO_DEVICE:
        return "No device has been supplied to load filesystem from";
    case DEV_CLOSED:
        return "The supplied device is closed";
    case INV_LFN_COMP:
        return "Invalid Long Filename component";
    case LOOP_DETECTED:
        return "Loop detected in File Allocation Table";
    case BPB_WARNING:
        return "Possible error detected in Volume Boot Record. This may "
                "result in unpredictable behaviour.";
    case FAT_RES_A:
        return "Reserved value 0x001 encountered in File Allocation Table";
    case FAT_RES_B:
        return "Reserved value between 0xFF0 and 0xFF6 encountered in File "
                "Allocation Table";
    case FAT_CLUST_BAD:
        return "Encountered a cluster marked as BAD while reading from the "
                "File Allocation Table";
    case BPB_FATAL:
        return "Encountered a fatal error attempting to load the Volume Boot"
                " Record. The filesystem can not be loaded.";
    default:
        return "Unknown Error Code " + QString::number(err);
    }
}

QByteArray Util::swapEndian(QByteArray b){
    QByteArray result;
    for (int i = (b.size() - 1); i >= 0; i--) {
        result.append(b.at(i));
    }

    return result;
}

int Util::byteArrayToIntS(QByteArray b) {
    return byteArrayToInt(swapEndian(b));
}

int Util::byteArrayToInt(QByteArray b) {
    return byteArrayToInt(b,0);
}

int Util::byteArrayToInt(QByteArray b, int offset) {
    // turns four bytes into an integer.
    int value = 0, shift = 0;

    for (int i = 0; i < 4; i++) {
        shift = (3 - i) * 8;
        value += (b.at(i + offset) & 0x000000FF) << shift;
    }
    return value;
}

bool Util::getBit(char byte, int bit) {
    int i = byte >> (bit) & 0x00000001;

    if (i == 1) return true;
    else return false;
}

QByteArray Util::getBytes(QByteArray data, int start, int end, int length) {
    QByteArray qba = getBytes(data,start,end);

    // Now pad out to length.
    int nn = length - qba.size();

    for (int i = 1; i <= nn; i++) {
        qba.append('\0');
    }

    return qba;
}

QByteArray Util::getBytes(QByteArray data, int start, int end) {
    if (start < 0) qWarning() << "ERROR: Start is below 0";
    if (start >= data.size()) qWarning() << "ERROR: End is outside array";

    if (start == end) {
        QByteArray qba;
        qba.append(data.at(start));
        return qba;
    }
    if (end == start + 1) {
        QByteArray qba;
        qba.append(data.at(start));
        qba.append(data.at(end));
        return qba;
    }
    return data.mid(start,end-start);
}
