/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: fatentry.cpp
       Last Changed: $LastChangedDate: 2010-04-04 00:18:51 +1300 (Sun, 04 Apr 2010) $
           Revision: $Revision: 199 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2008,2009,2010
            License: GNU General Public License
   File Description: FATEntry implementation
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/

#include "fatentry.h"

FatEntry::FatEntry(DirEntPtr e, QString directory) {
    ent = e;
    entry_path = directory;
}

FSPlugin::Attributes FatEntry::getAttributes() const{
    FSPlugin::Attributes a(FSPlugin::A_NoAttributes);

    if (ent->isArchive())      a |= FSPlugin::A_Archive;
    if (ent->isSubdirectory()) a |= FSPlugin::A_Directory;
    if (ent->isHidden())       a |= FSPlugin::A_Hidden;
    if (ent->isReadOnly())     a |= FSPlugin::A_ReadOnly;
    if (ent->isSystem())       a |= FSPlugin::A_System;

    return a;
}

bool FatEntry::isDirectory() const{
    return ent->isSubdirectory();
}

quint64 FatEntry::getSize() const{
    return ent->size();
}

QString FatEntry::baseName() const{
    return ent->baseName();
}

QString FatEntry::suffix() const{
    return ent->extension();
}

QString FatEntry::fileName() const{
    return ent->fileName();
}

QString FatEntry::filePath() const {
    QString p = path();
    if (!p.endsWith("/")) p.append("/");
    return p.append(fileName());
}

QString FatEntry::path() const{
    return entry_path;
}

QDate FatEntry::getDate(DateType dt) const {
    if (dt == FSEntry::D_CreatedDate) return ent->created().date();
    if (dt == FSEntry::D_ModifiedDate) return ent->modified().date();
    if (dt == FSEntry::D_AccessedDate) return ent->accessDate();

    // An invalid date type was specified - probably a time was asked for.
    // Return an invalid QDate.
    return QDate();
}


QTime FatEntry::getTime(DateType dt) const {
    if (dt == FSEntry::D_CreatedTime) return ent->created().time();
    if (dt == FSEntry::D_ModifiedTime) return ent->modified().time();

    // an invalid date type was specified - probably a date was asked for,
    // or perhaps an access time (which FAT12 doesnt store). Return an invalid
    // QTime.
    return QTime();
}

QIcon FatEntry::getIcon() const{
#ifdef Q_OS_WIN32
    if (isDirectory()) {
        QFileIconProvider i;
        return i.icon(QFileIconProvider::Folder);
    }
    else {
        QPixmap qpm = winutils::getFileIcon(fileName(), false);
        QIcon i;
        i.addPixmap(qpm);
        qpm = winutils::getFileIcon(fileName(),true);
        i.addPixmap(qpm);
        return i;
    }
#else
    QFileIconProvider i;
    if (isDirectory())
        return i.icon(QFileIconProvider::Folder);
    else
        return i.icon(QFileIconProvider::File);
#endif
}

// FSPlugin v2 functions to expose short filenames:
QString FatEntry::altBaseName() const {
    return ent->shortBaseName();
}

QString FatEntry::altSuffix() const {
    return ent->shortExtension();
}

QString FatEntry::altFileName() const {
    return ent->shortFilename();
}

QString FatEntry::altFilePath() const {
    QString p = path();
    if (!p.endsWith("/")) p.append("/");
    return p.append(altFileName());
}
