/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: winutils.h
         Start Date: unknown - ask subversion
       Last Changed: $LastChangedDate: 2011-04-09 00:17:11 +1200 (Sat, 09 Apr 2011) $
           Revision: $Revision: 295 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2008,2009,2010
            License: GNU General Public License
   File Description: Windows-specific utility functions header
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/

#ifndef WINUTILS_H
#define WINUTILS_H

#include <QtGlobal>

#ifdef Q_OS_WIN32
#include <QPixmap>
#include <QString>
#include <windows.h>

namespace winutils {


    /** Converts a Windows HICON to a QPixmap while converting the alpha
      channel.

      This method was taken straight from qpixmap_win.cpp with only minor
      changes. The original was licensed under both the GNU GPL and GNU LGPL
      and is (C) Copyright Nokia Corporation. Version 4.5 of Qt was used.

      \param icon The icon to convert.
      \returns The input icon as a QPixmap.
     */
    QPixmap alphaPixmap( HICON const &icon);


    /** Gets the icon for a file on a windows system using the shell API.

      \param path The name of the file. The file does not have to exist.
      \param large If true, the large icon will be returned. Otherwise, the
            small icon will be returned.
      \param alpha If true, alpha channel conversion will be performed. If
            false, no alpha channel conversion will be performed.
      \returns The icon for the specified filename as a QPixmap.
     */
    QPixmap getFileIcon(QString path, bool large, bool alpha);

    /** Gets the icon for a file on a windows system using the shell API and
      converts it to a QPixmap doing alpha channel conversion along the way.

      \param path The name of the file. The file does not have to exist.
      \param large If true, the large icon will be returned. Otherwise, the
            small icon will be returned.
      \returns The icon for the specified filename as a QPixmap.
     */
    QPixmap getFileIcon(QString path, bool large);
}
#endif

#endif // WINUTILS_H
