/* Project "DIMG" Raw Image File Format Plugin
 *
 * This Software (C) Copyright David Goodwin, 2010.
 *
 *   This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "FPlibdsk.h"

bool FPlibdsk::fileIsSupported(QString filename) {
    qDebug() << "FPraw: Format support status requested for " << filename;

    QFileInfo fi;

    fi.setFile(filename);

    if (fi.completeSuffix().compare("img",Qt::CaseInsensitive) == 0)
        return true;
    if (fi.completeSuffix().compare("ima",Qt::CaseInsensitive) == 0)
        return true;
    if (fi.completeSuffix().compare("flp",Qt::CaseInsensitive) == 0)
        return true;
    return false;
}

QStringList FPlibdsk::getNameFilters() {
    QStringList filters;

    filters << "Raw Image Files (*.img *.ima *.flp)";

    return filters;
}

ImageFile *FPlibdsk::createImageFile(QString filename,
                                  ImageFilePlugin::LoadHints hints,
                                  long long expectedSize) {

    if (!fileIsSupported(filename)) {
        qDebug() << "WARNING: Specified file is unsupported by plugin.";
        return 0;
    }

    LibDskImageFile *rif = new LibDskImageFile(this);

    rif->open(filename,
              hints.testFlag(ImageFilePlugin::LH_Create),
              !hints.testFlag(ImageFilePlugin::LH_NoCache),
              expectedSize);

    return rif;
}

ImageFilePlugin::Features FPlibdsk::getFeatures() const {

    QScopedPointer<QSettings> settings;
    QString filename;
    filename = QCoreApplication::applicationName() + ".ini";
    qDebug() << "Checking for configuration file " << filename;

    if (QFile::exists(filename)) {
        // Load settings from there
        settings.reset(new QSettings(filename, QSettings::IniFormat, 0));
    } else {
        settings.reset(new QSettings());
    }

    bool enableRawSupport = settings->value("/FileHandling/FPLibDsk/EnableRaw",
                                             false).toBool();

    ImageFilePlugin::Features supportedFeatures;

    supportedFeatures |= ImageFilePlugin::F_Read;
    supportedFeatures |= ImageFilePlugin::F_Write;
    supportedFeatures |= ImageFilePlugin::F_FloppyDisk;

    if (enableRawSupport)
        supportedFeatures |= ImageFilePlugin::F_RawFormat;

    return supportedFeatures;
}

Q_EXPORT_PLUGIN2(FPlibdsk, FPlibdsk)
