/*
-----------------------------------------------------
   Application Name: DIMG
          File Name: fpraw.cpp
         Start Date: 27/02/2010
       Last Changed: $LastChangedDate: 2011-04-09 00:17:11 +1200 (Sat, 09 Apr 2011) $
           Revision: $Revision: 295 $
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
   File Description: RAW Image file plugin implementation
-----------------------------------------------------
        This file is part of DIMG.

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

File Notes:
------------------
*/


#include "FPraw.h"

bool FPraw::fileIsSupported(QString filename) {
    qDebug() << "FPraw: Format support status requested for " << filename;

    QFileInfo fi;

    fi.setFile(filename);

    if (fi.completeSuffix().compare("img",Qt::CaseInsensitive) == 0)
        return true;
    if (fi.completeSuffix().compare("ima",Qt::CaseInsensitive) == 0)
        return true;
    if (fi.completeSuffix().compare("flp",Qt::CaseInsensitive) == 0)
        return true;
    return false;
}

QStringList FPraw::getNameFilters() {
    QStringList filters;

    filters << "Raw Image Files (*.img *.ima *.flp)";

    return filters;
}

ImageFile *FPraw::createImageFile(QString filename,
                                  ImageFilePlugin::LoadHints hints,
                                  long long expectedSize) {

    if (!fileIsSupported(filename)) {
        qDebug() << "WARNING: Specified file is unsupported by plugin.";
        return 0;
    }

    RawImageFile *rif = new RawImageFile(this);

    rif->open(filename,
              hints.testFlag(ImageFilePlugin::LH_Create),
              !hints.testFlag(ImageFilePlugin::LH_NoCache),
              expectedSize);

    return rif;
}

Q_EXPORT_PLUGIN2(FPraw, FPraw)
